/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright 1993, University Corporation for Atmospheric Research           *
 * See netcdf/COPYRIGHT file for copying and redistribution conditions.      *
 *                                                                           *
 * Copyright by The HDF Group.                                               *
 * Copyright by the Board of Trustees of the University of Illinois.         *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of HDF.  The full HDF copyright notice, including       *
 * terms governing use, modification, and redistribution, is contained in    *
 * the COPYING file, which can be found at the root of the source code       *
 * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
 * If you do not have access to either file, you may request a copy from     *
 * help@hdfgroup.org.                                                        *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* $Id$ */
#ifndef _NC_ERROR_
#define _NC_ERROR_

#include "H4api_adpt.h"

#ifndef NO_STDARG
HDFLIBAPI void nc_serror(const char *fmt, ...) ;
HDFLIBAPI void NCadvise(int err, const char *fmt,...) ;
#else
HDFLIBAPI void nc_serror() ;
HDFLIBAPI void NCadvise() ;
#endif /* NO_STDARG */

#endif /* _NC_ERROR_ */
